[![Task Status](https://firefox-ci-tc.services.mozilla.com/api/github/v1/repository/{{cookiecutter.github_slug}}/main/badge.svg)](https://firefox-ci-tc.services.mozilla.com/api/github/v1/repository/{{cookiecutter.github_slug}}/main/latest)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/{{cookiecutter.github_slug}}/main.svg)](https://results.pre-commit.ci/latest/github/{{cookiecutter.github_slug}}/main)
[![Code Coverage](https://codecov.io/gh/{{cookiecutter.github_slug}}/branch/main/graph/badge.svg?token=GJIV52ZQNP)](https://codecov.io/gh/{{cookiecutter.github_slug}})
[![Documentation Status](https://readthedocs.org/projects/{{cookiecutter.__project_slug}}/badge/?version=latest)](https://{{cookiecutter.__project_slug}}.readthedocs.io/en/latest/?badge=latest)
[![License](https://img.shields.io/badge/license-MPL%202.0-orange.svg)](http://mozilla.org/MPL/2.0)

# {{cookiecutter.project_name}}

{{cookiecutter.short_description}}
